@@ -40,6 +40,15 @@ typedef u_int8_t	__u8;
 #ifndef IPV6_RECVERR
 #define IPV6_RECVERR	25
 #endif
+/* older glibc compatibility
+ * From rfc 3542:
+ * -  Changed the name of ICMPv6 unreachable code 2 to be "beyond scope
+ *    of source address."  ICMP6_DST_UNREACH_NOTNEIGHBOR was removed
+ *    with this change.
+ */
+#if defined(ICMP6_DST_UNREACH_NOTNEIGHBOR) && !defined(ICMP6_DST_UNREACH_BEYONDSCOPE)
+# define ICMP6_DST_UNREACH_BEYONDSCOPE ICMP6_DST_UNREACH_NOTNEIGHBOR
+#endif
 
 #define MAXHOPS		255
 #define MAXPROBES	6
@@ -355,7 +364,7 @@ usage(int exval)
 {
 	fprintf(stderr,
 	"usage: traceroute [-nFV] [-f first_ttl] [-m max_hops] [-p port]\n"
-	"           [-S source_addr] [-I interface]\n"
+	"           [-S source_addr] [-I interface] [-g gateway]\n"
 	"           [-t tos] [-w timeout] [-q nqueries] host [packetlen]\n");
 	exit(1);
 }
@@ -675,7 +684,7 @@ probe_recv(struct probe *p)
 				errstring = "N!";
 				break;
 
-			case ICMP6_DST_UNREACH_NOTNEIGHBOR:
+			case ICMP6_DST_UNREACH_BEYONDSCOPE:
 			case ICMP6_DST_UNREACH_ADDR:
 				errstring = "H!";
 				break;
